<?php

/**
 * xFile PHP Class
 * 
 * This class provides methods to interact with the xFile service, 
 * enabling file storage and retrieval operations.
 * 
 * @author xTEAM
 * @license MIT License
 * @link https://api.xfile.pw
 */
class xFile
{

    private $url = 'https://api.xfile.pw';
    private $authToken;

    /**
     * Constructor
     * 
     * Initializes a new instance of the xFile class with the provided authentication token.
     * 
     * @param string $authToken The authentication token for accessing the xFile service.
     */
    public function __construct($authToken)
    {
        $this->authToken = $authToken;
    }

    /**
     * Executes a GET request to the specified URL and returns the result as an associative array.
     * 
     * @param string $token The authentication token to include in the request headers.
     * @param string $url The URL to send the GET request to.
     * @return array An associative array containing the result of the GET request.
     */
    protected function GetLoad($url, $token)
    {
        $curl = curl_init($url);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, "GET");
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, 1);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl, CURLOPT_HTTPHEADER, [
            'xFile: Bearer ' . $token,
            'Content-Type: application/json',
        ]);
        $resultdata = curl_exec($curl);
        $resultArray = json_decode($resultdata, true);
        curl_close($curl);
        return $resultArray;
    }

    /**
     * Executes a POST request to the specified URL with the provided data and returns the result as an associative array.
     * 
     * @param string $url The URL to send the POST request to.
     * @param string $token The authentication token to include in the request headers.
     * @param array $postData The data to include in the POST request body.
     * @return array An associative array containing the result of the POST request.
     */
    protected function Postload($url, $token, $postData)
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($postData));
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'xFile: Bearer ' . $token,
            'Content-Type: application/json',
        ]);
        $result = curl_exec($ch);
        curl_close($ch);
        return json_decode($result, true);
    }

    /**
     * Uploads a file to the xFile service and returns information about the uploaded file.
     * 
     * @param string $id The ID of the file to upload.
     * @return array An associative array containing information about the uploaded file.
     */
    public function Store($id)
    {
        $data = ['file_id' => $id];
        $url = $this->url . '/v1/store?file_id=' . $id;
        $data = $this->Postload($url, $this->authToken, $data);
        return $data;
    }

    /**
     * Retrieves information about a file stored on the xFile service.
     * 
     * @param string $id The ID of the file to retrieve information about.
     * @return array An associative array containing information about the specified file.
     */
    public function Info($id)
    {
        $url = $this->url . '/v1/info?file_id=' . $id;
        $data = $this->GetLoad($url, $this->authToken);
        return $data;
    }
}
